==> jc-1.4.0.tar.gz: ppg/code/ScanCode.h <==
// public class ppg.code.ScanCode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ff40332975ef3bc9 ppg_code_Code
// @dep_class 2c65e37ebdf339b2 ppg_code_ScanCode

// header file dependencies
// @dep_header ppg_code_Code

#include "ppg/code/Code.h"

#ifndef _JC_ppg_code_ScanCode_H_
#define _JC_ppg_code_ScanCode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_code_ScanCode$sub_refs	_jc_ppg_code_ScanCode$sub_refs;
typedef struct _jc_ppg_code_ScanCode$sub_nonrefs	_jc_ppg_code_ScanCode$sub_nonrefs;
typedef struct _jc_ppg_code_ScanCode$refs	_jc_ppg_code_ScanCode$refs;
typedef struct _jc_ppg_code_ScanCode$nonrefs	_jc_ppg_code_ScanCode$nonrefs;
typedef struct _jc_ppg_code_ScanCode$object	_jc_ppg_code_ScanCode$object;

typedef const struct _jc_ppg_code_ScanCode$vmethods	_jc_ppg_code_ScanCode$vmethods;
typedef const struct _jc_ppg_code_ScanCode$vtable	_jc_ppg_code_ScanCode$vtable;
typedef const struct _jc_ppg_code_ScanCode$vtype	_jc_ppg_code_ScanCode$vtype;

// Constructors
extern void _jc_ppg_code_ScanCode$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_code_ScanCode$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_code_ScanCode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_code_ScanCode$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_code_ScanCode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_code_ScanCode$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_code_ScanCode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_code_ScanCode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_code_ScanCode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_code_ScanCode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_code_ScanCode$object *);
};

// Vtable
struct _jc_ppg_code_ScanCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_code_Code$vmethods	ppg_code_Code;
	_jc_ppg_code_ScanCode$vmethods	ppg_code_ScanCode;
};

// Vtype
struct _jc_ppg_code_ScanCode$vtype {
	_jc_type			type;
	_jc_ppg_code_ScanCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_code_ScanCode$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_code_ScanCode$refs {
    _jc_ppg_code_ScanCode$sub_refs	ppg_code_ScanCode;
    _jc_ppg_code_Code$sub_refs	ppg_code_Code;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_code_ScanCode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_code_ScanCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_code_Code$sub_nonrefs	ppg_code_Code;
    _jc_ppg_code_ScanCode$sub_nonrefs	ppg_code_ScanCode;
};

// Object instance structure
struct _jc_ppg_code_ScanCode$object {
	_jc_ppg_code_ScanCode$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_code_ScanCode$vtype	*vtype;
	_jc_ppg_code_ScanCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_code_ScanCode$vtype _jc_ppg_code_ScanCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_code_ScanCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_code_ScanCode$class_object;

#endif	/* _JC_ppg_code_ScanCode_H_ */

==> jc-1.4.6.tar.gz: ppg/code/ScanCode.h <==
// public class ppg.code.ScanCode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ff40332975ef3bc9 ppg_code_Code
// @dep_class 2c65e37ebdf339b2 ppg_code_ScanCode

// header file dependencies
// @dep_header ppg_code_Code

#include "ppg/code/Code.h"

#ifndef _JC_ppg_code_ScanCode_H_
#define _JC_ppg_code_ScanCode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_code_ScanCode$sub_refs	_jc_ppg_code_ScanCode$sub_refs;
typedef struct _jc_ppg_code_ScanCode$sub_nonrefs	_jc_ppg_code_ScanCode$sub_nonrefs;
typedef struct _jc_ppg_code_ScanCode$refs	_jc_ppg_code_ScanCode$refs;
typedef struct _jc_ppg_code_ScanCode$nonrefs	_jc_ppg_code_ScanCode$nonrefs;
typedef struct _jc_ppg_code_ScanCode$object	_jc_ppg_code_ScanCode$object;

typedef const struct _jc_ppg_code_ScanCode$vmethods	_jc_ppg_code_ScanCode$vmethods;
typedef const struct _jc_ppg_code_ScanCode$vtable	_jc_ppg_code_ScanCode$vtable;
typedef const struct _jc_ppg_code_ScanCode$vtype	_jc_ppg_code_ScanCode$vtype;

// Constructors
extern void _jc_ppg_code_ScanCode$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_code_ScanCode$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_code_ScanCode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_code_ScanCode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_code_ScanCode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_code_ScanCode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_code_ScanCode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_code_ScanCode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_code_ScanCode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_code_ScanCode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_code_ScanCode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_code_ScanCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_code_Code$vmethods	ppg_code_Code;
	_jc_ppg_code_ScanCode$vmethods	ppg_code_ScanCode;
};

// Vtype
struct _jc_ppg_code_ScanCode$vtype {
	_jc_type			type;
	_jc_ppg_code_ScanCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_code_ScanCode$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_code_ScanCode$refs {
    _jc_ppg_code_ScanCode$sub_refs	ppg_code_ScanCode;
    _jc_ppg_code_Code$sub_refs	ppg_code_Code;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_code_ScanCode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_code_ScanCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_code_Code$sub_nonrefs	ppg_code_Code;
    _jc_ppg_code_ScanCode$sub_nonrefs	ppg_code_ScanCode;
};

// Object instance structure
struct _jc_ppg_code_ScanCode$object {
	_jc_ppg_code_ScanCode$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_code_ScanCode$vtype	*vtype;
	_jc_ppg_code_ScanCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_code_ScanCode$vtype _jc_ppg_code_ScanCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_code_ScanCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_code_ScanCode$class_object;

#endif	/* _JC_ppg_code_ScanCode_H_ */
